Struct Session

pub struct Session<'hir> { /* private fields */ }
Hir session

This struct represents a hir compilation session It holds an arena with all the nodes of the tree, and a map to find nodes by their HirId

Implementations

Source

impl<'hir> Session<'hir>

pub fn set_root(&self, m: &'hir Module<'hir>)

pub fn get_root(&self) -> &'hir Module<'hir>

pub fn get_node(&self, id: &HirId) -> HirNodeKind<'hir>

Gets a node by their HirId. This functions assumes that the id is valid, and exists in the tree.

Panics
  • If the id dosn’t match a node in the graph
Source

impl<'hir> Session<'hir>

pub fn alloc_annon<T, C>(&self, val: T) -> &'hir T
where T: ArenaAllocable<'hir, C>,

pub fn alloc<T, C>(&self, val: T) -> &'hir T
where T: ArenaAllocable<'hir, C> + HirNode<'hir>,

pub fn alloc_iter<T, I, C>(&self, val: I) -> &'hir [T]
where T: ArenaAllocable<'hir, C> + HirNode<'hir>, I: IntoIterator<Item = T, IntoIter: ExactSizeIterator>,

pub fn alloc_iter_annon<T, I, C>(&self, val: I) -> &'hir [T]
where T: ArenaAllocable<'hir, C>, I: IntoIterator<Item = T, IntoIter: ExactSizeIterator>,